aboutsummaryrefslogtreecommitdiffstats
path: root/env.c
diff options
context:
space:
mode:
authorEric S. Raymond <esr@thyrsus.com>1998-11-30 21:34:58 +0000
committerEric S. Raymond <esr@thyrsus.com>1998-11-30 21:34:58 +0000
commit284eaa8a47a91d4cb0d67960899e5abeb9059614 (patch)
tree2fe01d3a1a0e2d0b8a728bbfe1fa7dc89405dc58 /env.c
parent51e95ea0156a0a05c905ade2d6b5bdd06a0782dc (diff)
downloadfetchmail-284eaa8a47a91d4cb0d67960899e5abeb9059614.tar.gz
fetchmail-284eaa8a47a91d4cb0d67960899e5abeb9059614.tar.bz2
fetchmail-284eaa8a47a91d4cb0d67960899e5abeb9059614.zip
Switch timestamp to GMT.
svn path=/trunk/; revision=2245
Diffstat (limited to 'env.c')
-rw-r--r--env.c11
1 files changed, 6 insertions, 5 deletions
diff --git a/env.c b/env.c
index ee6359c4..69996683 100644
--- a/env.c
+++ b/env.c
@@ -116,14 +116,15 @@ char *rfc822timestamp(void)
time(&now);
#ifdef HAVE_STRFTIME
/*
* Conform to RFC822. Note that we generate a 4-digit year here,
* avoiding Y2K hassles. Note: max length of this timestamp in an
* English locale should be 32 chars, assuming a 5-character timezone
* of the form [+-]nnnn. The only things that should vary by locale
* are the day and month abbreviations.
*/
strftime(buf, sizeof(buf)-1,
- "%a, %d %b %Y %H:%M:%S %z", localtime(&now));
+ "%a, %d %b %Y %H:%M:%S GMT", gmtime(&now));
#else
/*
* This is really just a portability fallback, as the
@@ -116,14 +116,15 @@ char *rfc822timestamp(void)
#ifdef HAVE_STRFTIME
/*
- * Conform to RFC822. Note that we generate a 4-digit year here,
- * avoiding Y2K hassles. Note: max length of this timestamp in an
- * English locale should be 32 chars, assuming a 5-character timezone
- * of the form [+-]nnnn. The only things that should vary by locale
+ * Conform to RFC822. GMT rather than local time because of the
+ * mess that %Z generates obsolete 822 syntax but %z is not
+ * guaranteed portable. We generate a 4-digit year here, avoiding
+ * Y2K hassles. Max length of this timestamp in an English locale
+ * should be 29 chars. The only things that should vary by locale
* are the day and month abbreviations.
*/